/*
    This file is part of libnsautils

    Copyright © 2010 Nokia Corporation and/or its subsidiary(-ies).
    All rights reserved.

    Contact: Moises Martinez Garcia <moises.martinez@nokia.com>

    This software, including documentation, is protected by copyright
    controlled by Nokia Corporation. All rights are reserved.

    Copying, including reproducing, storing, adapting or translating,
    any or all of this material requires the prior written consent of
    Nokia Corporation. This material also contains confidential
    information which may not be disclosed to others without the prior
    written consent of Nokia.
*/

#ifndef __LIBNSAUTILS_NSAUTILS_H__
#define __LIBNSAUTILS_NSAUTILS_H__

#include <QByteArray>
#include <QString>
#include <QUrl>
#include <QList>
#include <QIODevice>

#define DEFAULT_NSA_URL "https://ccds.serviceactivation.ext.nokia.com/api/v1/rest/"

namespace nsa
{
    namespace DetermineAccount
    {
        QByteArray makeQuery(const QString & aEmailAddress,
                             const QString & aCountryCode = "",
                             const QString & aNetworkCode = "",
                             const QString & aUserName = "",
                             const QString & aPassword = "");

        QByteArray makeUrlString(const QString & aEmailAddress,
                                 const QString & aCountryCode = "",
                                 const QString & aNetworkCode = "",
                                 const QString & aUserName = "",
                                 const QString & aPassword = "",
                                 const QByteArray & aUrl = DEFAULT_NSA_URL);

        QUrl makeUrl(const QString & aEmailAddress,
                     const QString & aCountryCode = "",
                     const QString & aNetworkCode = "",
                     const QString & aUserName = "",
                     const QString & aPassword = "",
                     const QByteArray & aUrl = DEFAULT_NSA_URL);

        struct SecurityInfo
        {
            bool auth : 1;
            bool ssl : 1;
            bool spa : 1;
            QString username;
            QString password;

            SecurityInfo() : auth(false), ssl(false), spa(false) {}
        };

        struct ConnInfo
        {
            int status;
            bool preferred;
            QString server;
            QString protocol;
            int port;
            SecurityInfo security;

            ConnInfo() : status(0), preferred(false), port(0) {}
        };

        typedef QList<ConnInfo> ConnInfoList;

        struct ConnectionsInfo
        {
            ConnInfoList connections;
            int preferred;

            ConnectionsInfo() : preferred(-1) {}
        };

        struct AccountInfo
        {
            QString address;
            QString username;
            QString password;
        };

        struct ProviderInfo
        {
            QString type;
            QString code;
            QString name;
            QString title;
            QString description;
            AccountInfo account;
            ConnectionsInfo incoming;
            ConnectionsInfo outgoing;
        };

        struct CcdsResponse
        {
            int status;
            int code;
            ProviderInfo provider;

            CcdsResponse() : status(0), code(0) {}
        };

        bool parseResponse(QIODevice * device, CcdsResponse & response);
    }
}
#endif // __LIBNSAUTILS_NSAUTILS_H__
